<?php
/**
 * Plugin Name: kitbe Core
 * Plugin URI: https://themeforest.net/user/droitthemes/portfolio
 * Description: This plugin adds the core features to the kitbe WordPress theme. You must have to install this plugin to get all the features included with the theme.
 * Version: 1.0.1
 * Author: DroitThemes
 * Author URI: https://themeforest.net/user/droitthemes/portfolio
 * Text domain: kitbe-core
 */

if ( !defined('ABSPATH') )
    die('-1');

// Make sure the same class is not loaded twice in free/premium versions.
if ( !class_exists( 'kitbe_core' ) ) {
	/**
	 * Main kitbe Core Class
	 *
	 * The main class that initiates and runs the kitbe Core plugin.
	 *
	 * @since 1.7.0
	 */
	class kitbe_core {
		/**
		 * kitbe Core Version
		 *
		 * Holds the version of the plugin.
		 *
		 * @since 1.7.0
		 * @since 1.7.1 Moved from property with that name to a constant.
		 *
		 * @var string The plugin version.
		 */
		const VERSION = '1.0' ;
		/**
		 * Minimum Elementor Version
		 *
		 * Holds the minimum Elementor version required to run the plugin.
		 *
		 * @since 1.7.0
		 * @since 1.7.1 Moved from property with that name to a constant.
		 *
		 * @var string Minimum Elementor version required to run the plugin.
		 */
		const MINIMUM_ELEMENTOR_VERSION = '1.7.0';
		/**
		 * Minimum PHP Version
		 *
		 * Holds the minimum PHP version required to run the plugin.
		 *
		 * @since 1.7.0
		 * @since 1.7.1 Moved from property with that name to a constant.
		 *
		 * @var string Minimum PHP version required to run the plugin.
		 */
		const  MINIMUM_PHP_VERSION = '5.4' ;
        /**
         * Plugin's directory paths
         * @since 1.0
         */
        const CSS = null;
        const JS = null;
        const IMG = null;
        const VEND = null;

		/**
		 * Instance
		 *
		 * Holds a single instance of the `kitbe-core` class.
		 *
		 * @since 1.7.0
		 *
		 * @access private
		 * @static
		 *
		 * @var kitbe-core A single instance of the class.
		 */
		private static  $_instance = null ;
		/**
		 * Instance
		 *
		 * Ensures only one instance of the class is loaded or can be loaded.
		 *
		 * @since 1.7.0
		 *
		 * @access public
		 * @static
		 *
		 * @return kitbe-core An instance of the class.
		 */
		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		/**
		 * Clone
		 *
		 * Disable class cloning.
		 *
		 * @since 1.7.0
		 *
		 * @access protected
		 *
		 * @return void
		 */
		public function __clone() {
			// Cloning instances of the class is forbidden
			_doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?', 'kitbe-core' ), '1.7.0' );
		}

		/**
		 * Wakeup
		 *
		 * Disable unserializing the class.
		 *
		 * @since 1.7.0
		 *
		 * @access protected
		 *
		 * @return void
		 */
		public function __wakeup() {
			// Unserializing instances of the class is forbidden.
			_doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?', 'kitbe-core' ), '1.7.0' );
		}

		/**
		 * Constructor
		 *
		 * Initialize the kitbe Core plugins.
		 *
		 * @since 1.7.0
		 *
		 * @access public
		 */
		public function __construct() {
			$this->init_hooks();
			$this->core_includes();
			do_action( 'kitbe_core_loaded' );
		}

		/**
		 * Include Files
		 *
		 * Load core files required to run the plugin.
		 *
		 * @since 1.7.0
		 *
		 * @access public
		 */
		public function core_includes() {
			// Extra functions
            //require_once __DIR__ . '/post-type/service.php';
            

            /**
             * Register widget area.
             *
             * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
             */
			require_once __DIR__ . '/wp-widgets/widgets.php';

			// Elementor custom field icons
			require_once __DIR__ . '/fields/icons.php';

            // RGBA color picker
            require plugin_dir_path(__FILE__) . '/acf-rgba-color-picker/acf-rgba-color-picker.php';

            // ACF Metaboxes
          
		}


		/**
		 * Init Hooks
		 *
		 * Hook into actions and filters.
		 *
		 * @since 1.7.0
		 *
		 * @access private
		 */
		private function init_hooks() {
			add_action( 'init', [ $this, 'i18n' ] );
			add_action( 'plugins_loaded', [ $this, 'init' ] );
		}

		/**
		 * Load Textdomain
		 *
		 * Load plugin localization files.
		 *
		 * @since 1.7.0
		 *
		 * @access public
		 */
		public function i18n() {
			load_plugin_textdomain( 'kitbe-core', false, plugin_basename( dirname( __FILE__ ) ) . '/languages' );
		}



		/**
		 * Init kitbe Core
		 *
		 * Load the plugin after Elementor (and other plugins) are loaded.
		 *
		 * @since 1.0.0
		 * @since 1.7.0 The logic moved from a standalone function to this class method.
		 *
		 * @access public
		 */
		public function init() {

			if ( !did_action( 'elementor/loaded' ) ) {
				add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
				return;
			}

			// Check for required Elementor version

			if ( !version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
				add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
				return;
			}

			// Check for required PHP version

			if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
				add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
				return;
			}

			// Add new Elementor Categories
			add_action( 'elementor/init', [ $this, 'add_elementor_category' ] );

			// Register Widget Scripts
			add_action( 'elementor/frontend/after_register_scripts', [ $this, 'register_widget_scripts' ] );
			add_action( 'elementor/editor/before_enqueue_scripts', [ $this, 'register_widget_scripts' ] );
            add_action( 'wp_enqueue_scripts', [ $this, 'enqueue_scripts' ] );

			// Register Widget Scripts
			add_action( 'elementor/frontend/after_enqueue_styles', [ $this, 'enqueue_widget_styles' ] );
			add_action( 'elementor/editor/before_enqueue_scripts', [ $this, 'enqueue_widget_styles' ] );

			// Register New Widgets
			add_action( 'elementor/widgets/widgets_registered', [ $this, 'on_widgets_registered' ] );
		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have Elementor installed or activated.
		 *
		 * @since 1.1.0
		 * @since 1.7.0 Moved from a standalone function to a class method.
		 *
		 * @access public
		 */
		public function admin_notice_missing_main_plugin() {
			$message = sprintf(
			/* translators: 1: kitbe Core 2: Elementor */
				esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'kitbe-core' ),
				'<strong>' . esc_html__( 'kitbe core', 'kitbe-core' ) . '</strong>',
				'<strong>' . esc_html__( 'Elementor', 'kitbe-core' ) . '</strong>'
			);
			printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have a minimum required Elementor version.
		 *
		 * @since 1.1.0
		 * @since 1.7.0 Moved from a standalone function to a class method.
		 *
		 * @access public
		 */
		public function admin_notice_minimum_elementor_version() {
			$message = sprintf(
			/* translators: 1: kitbe Core 2: Elementor 3: Required Elementor version */
				esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'kitbe-core' ),
				'<strong>' . esc_html__( 'kitbe Core', 'kitbe-core' ) . '</strong>',
				'<strong>' . esc_html__( 'Elementor', 'kitbe-core' ) . '</strong>',
				self::MINIMUM_ELEMENTOR_VERSION
			);
			printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have a minimum required PHP version.
		 *
		 * @since 1.7.0
		 *
		 * @access public
		 */
		public function admin_notice_minimum_php_version() {
			$message = sprintf(
			/* translators: 1: kitbe Core 2: PHP 3: Required PHP version */
				esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'kitbe-core' ),
				'<strong>' . esc_html__( 'kitbe Core', 'kitbe-core' ) . '</strong>',
				'<strong>' . esc_html__( 'PHP', 'kitbe-core' ) . '</strong>',
				self::MINIMUM_PHP_VERSION
			);
			printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
		}

		/**
		 * Add new Elementor Categories
		 *
		 * Register new widget categories for kitbe Core widgets.
		 *
		 * @since 1.0.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access public
		 */
		public function add_elementor_category() {
			\Elementor\Plugin::instance()->elements_manager->add_category( 'kitbe-elements', [
				'title' => __( 'kitbe Elements', 'kitbe-core' ),
			], 1 );
		}

		/**
		 * Register Widget Scripts
		 *
		 * Register custom scripts required to run kitbe Core.
		 *
		 * @since 1.6.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access public
		 */
		public function register_widget_scripts() {

			//wp_enqueue_style('flexslider', plugins_url( 'assets/vendors/flex/css/flexslider.css', __FILE__ ) );
           // wp_enqueue_style('animate',  plugins_url( 'assets/vendors/animation/animate.css', __FILE__ ) );


			if ( !is_admin() ) {
				wp_deregister_script( 'jquery' );
				wp_register_script( 'jquery', plugins_url( 'assets/js/jquery-3.4.1.min.js', __FILE__ ), false, '3.4.1' );
				wp_enqueue_script( 'jquery' );
			}

           //wp_enqueue_script( 'jquery-min', plugins_url('assets/js/jquery-3.4.1.min.js', __FILE__), array('jquery'), '3.4.1', true );
           wp_enqueue_script( 'popper-min', plugins_url('assets/js/popper.min.js', __FILE__), array('jquery'), '1.0.0', true );
           wp_enqueue_script( 'bootstrap-min', plugins_url('assets/js/bootstrap.min.js', __FILE__), array('jquery'), '4.4.1', true );
           //wp_enqueue_script( 'carousel-min', plugins_url('assets/js/carousel-min.js', __FILE__), array('jquery'), '2.3.4', true );
           //wp_enqueue_script( 'carousel2-min', plugins_url('assets/js/owl.carousel2.thumbs.min.js', __FILE__), array('jquery'), '0.1.8', true );
           //wp_enqueue_script( 'parallax-min', plugins_url('assets/js/parallax.min.js', __FILE__), array('jquery'), '1.5.0', true );
           wp_enqueue_script( 'aos-js', plugins_url('assets/js/aos.js', __FILE__), array('jquery'), '1.0.0', true );
           //wp_enqueue_script( 'magnific-min', plugins_url('assets/js/jquery.magnific-popup.min.js', __FILE__), array('jquery'), '1.1.0', true );

           wp_enqueue_script( 'imagesloaded' );

           wp_enqueue_script( 'isotope-pkgd-min', plugins_url('assets/js/isotope.pkgd.min.js', __FILE__), array('jquery'), '3.0.6', true );
           wp_enqueue_script( 'masonry-pkgd-min', plugins_url('assets/js/masonry.pkgd.min.js', __FILE__), array('jquery'), '4.2.2', true );
           wp_enqueue_script( 'gmap', plugins_url('assets/js/gmaps.js', __FILE__), array('jquery'), '6.0.0', true );
           wp_enqueue_script( 'mCustomScrollbar', plugins_url('assets/js/mCustomScrollbar.js', __FILE__), array('jquery'), '2.3.2', true );
          //wp_enqueue_script( 'custom', plugins_url('assets/js/custom.js', __FILE__), array('jquery'), '1.0.0', true );
           

            

		}

		/**
		 * Register Widget Styles
		 *
		 * Register custom styles required to run kitbe Core.
		 *
		 * @since 1.7.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access public
		 */
		
		public function enqueue_widget_styles() {



            if ( defined('ELEMENTOR_VERSION') ) {
                if ( \Elementor\Plugin::$instance->preview->is_preview_mode() ) {
                    wp_enqueue_style( 'owl-carousel' );
                    wp_enqueue_style( 'appart-style' );
                    wp_enqueue_style( 'appart-responsive' );
                }
            }


		}

		public function enqueue_scripts() {

		}




		/*public function register_admin_styles() {
            wp_enqueue_style( 'kitbe_core_admin', plugins_url( 'assets/css/kitbe-core-admin.css', __FILE__ ) );
        }*/

		/**
		 * Register New Widgets
		 *
		 * Include kitbe Core widgets files and register them in Elementor.
		 *
		 * @since 1.0.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access public
		 */
		public function on_widgets_registered() {
			$this->include_widgets();
			$this->register_widgets();
		}

		/**
		 * Include Widgets Files
		 *
		 * Load kitbe Core widgets files.
		 *
		 * @since 1.0.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access private
		 */
		private function include_widgets() {
			require_once __DIR__ . '/widgets/kitbe_hero_slide.php';
			require_once __DIR__ . '/widgets/kitbe_blog.php';
			require_once __DIR__ . '/widgets/kitbe_client_say.php';
		
        }

		/**
		 * Register Widgets
		 *
		 * Register kitbe Core widgets.
		 *
		 * @since 1.0.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access private
		 */
		private function register_widgets() {
			// Site Elements
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \kitbeCore\Widgets\kitbe_hero_slide() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \kitbeCore\Widgets\kitbe_blog() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \kitbeCore\Widgets\kitbe_client_say() );
			
        }
	}
}
// Make sure the same function is not loaded twice in free/premium versions.

if ( !function_exists( 'kitbe_core_load' ) ) {
	/**
	 * Load kitbe Core
	 *
	 * Main instance of kitbe_Core.
	 *
	 * @since 1.0.0
	 * @since 1.7.0 The logic moved from this function to a class method.
	 */
	function kitbe_core_load() {
		return kitbe_core::instance();
	}

	// Run kitbe Core
    kitbe_core_load();
}


function kitbe_admin_cpt_script( $hook ) {

    global $post;

    if ( $hook == 'post-new.php' || $hook == 'post.php' ) {
        if ( 'service' === $post->post_type ) {
            wp_enqueue_style('themify-icons', plugins_url( 'assets/vendors/themify-icon/themify-icons.css', __FILE__ ));
        }
    }
}
add_action( 'admin_enqueue_scripts', 'kitbe_admin_cpt_script', 10, 1 );