<?php
namespace kitbeCore\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;
use WP_Query;
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}
/**
 * Text Typing Effect
 *
 * Elementor widget for text typing effect.
 *
 * @since 1.7.0
 */
class kitbe_blog extends Widget_Base {
    public function get_name() {
        return 'kitbe_blog';
    }

    public function get_title() {
        return esc_html__( 'Blog Section', 'kitbe-core' );
    }

    public function get_icon() {
        return 'eicon-info-box';
    }

    public function get_categories() {
        return [ 'kitbe-elements' ];
    }

    protected function _register_controls() {
   // ----------------------------------------  Blog Design ------------------------------
        $this->start_controls_section(
            'blog_design',
            [
                'label' => __( 'Blog Style', 'kitbe-core' ),
            ]
        );
        $this->add_control(
            'blog_design_seting', [
                'label' => __( 'Blog Style', 'kitbe-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => __( 'Style One', 'kitbe-core' ),
                    '2' => __( 'Style Two', 'kitbe-core' )
                ],
                'default' => '1'
            ]
        );
        $this->end_controls_section(); // End Blog Style 
        // ----------------------------------------  About content ------------------------------
        $this->start_controls_section(
            'blog',
            [
                'label' => __( 'Blog Section', 'kitbe-core' ),
            ]
        );
        $this->add_control(
            'sec_title',
            [
                'label' => esc_html__( 'Blog Title', 'kitbe-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Recent post'
            ]
        );
        $this->add_control(
            'sec_sub_title',
            [
                'label' => esc_html__( 'Blog Sub Title', 'kitbe-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Dont get shirty with me chinwag say bleeder hanky panky so I said bugger all mate such a fibber'
            ]
        );
        
        $this->end_controls_section(); // End Blog Section 
        //---------------- Style Section --------------- // 

        $this->start_controls_section(
            'blog_style', [
                'label' => __( 'Blog Title', 'kitbe-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color', [
                'label' => __( 'Title Text Color', 'appart-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title .title-text' => 'color: {{VALUE}};', 
                ],
            ]
        );

         $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'label' => 'Typography',
                'name' => 'typography_title',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .section-title .title-text',
                
            ]
        );

        $this->add_control(
            'sub_title_color', [
                'label' => __( 'Sub Title Color', 'kitbe-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title .sub_title' => 'color: {{VALUE}};', 
                ],  
            ]
        );
         $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'label' => 'Typography',
                'name' => 'typography_sub_title',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .section-title .sub_title',  
            ]
        );

      $this->end_controls_section();   
      /// End The Blog Sub Title Section
       $this->start_controls_section(
            'blog_filter', [
                'label' => __( 'Blog Settings', 'kitbe-core' ),
            ]
        );

        $this->add_control(
            'all_label', [
                'label' => esc_html__( 'All filter label', 'kitbe-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'See All'
            ]
        );


        $this->add_control(
            'show_count', [
                'label' => esc_html__( 'Show count', 'kitbe-core' ),
                'type' => Controls_Manager::NUMBER,
                'label_block' => true,
                'default' => 8
            ]
        );

        $this->add_control(
            'order', [
                'label' => esc_html__( 'Order', 'kitbe-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'ASC' => 'ASC',
                    'DESC' => 'DESC'
                ],
                'default' => 'ASC'
            ]
        );
     $this->end_controls_section();

  }
    protected function render() {
    $this->load_widget_script();
    $settings = $this->get_settings(); 
    $blog_format = $settings['blog_design_seting'];

    $sec_title     = $settings['sec_title'];
    $sec_sub_title = $settings['sec_sub_title'];

    $blogPost = new WP_Query(array(
            'post_type'     => 'post',
            'posts_per_page'=> $settings['show_count'],
            'order' => $settings['order'],
            'post__not_in' => !empty($settings['exclude']) ? explode(',', $settings['exclude']) : ''
    ));   
?>
<?php if($blog_format == '1'){ ?>
<!-- blog-section - start ================================================== -->
<section id="blog-section" class="blog-section sec-ptb-120 deco-wrap clearfix">
    <div class="container">
        <div class="row mb-60 justify-content-center">
            <div class="col-lg-6 col-md-7 col-sm-8 col-xs-12" data-aos="fade-up" data-aos-delay="100">
                <div class="section-title text-center">
                    <?php if(!empty($sec_title)): ?>
                    <h2 class="title-text mb-15"><?php echo wp_kses_post($sec_title); ?></h2>
                    <?php endif; ?>
                    <?php if(!empty($sec_sub_title)): ?>
                    <p class="mb-0 sub_title"><?php echo wp_kses_post($sec_sub_title); ?></p>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <div class="row justify-content-lg-between justify-content-md-center justify-content-sm-center">
            <?php if ( $blogPost->have_posts() ) : ?>
             <?php while ( $blogPost->have_posts() ) : $blogPost->the_post(); ?>
            <div class="col-lg-4 col-md-4 col-sm-4 col-xs-12" data-aos="fade-up" data-aos-delay="300">
                <div class="blog-primary">
                    <?php 
                         if(has_post_thumbnail()):
                            the_post_thumbnail('', array('class' => 'item-image mb-30 rounded'));
                         endif; 
                      ?>
                    <div class="item-content">
                        <span class="post-date"><?php echo get_the_date(); ?></span>
                        <h3 class="item-title">
                            <a href="<?php the_permalink(); ?>"><?php echo wp_trim_words( get_the_title(), 5, false ); ?></a>
                        </h3>
                        <p class="mb-0">
                           <?php echo wp_trim_words( get_the_content(), 30, false ); ?>
                        </p>
                    </div>
                </div>
            </div>
            <?php endwhile; ?>
            <?php
             wp_reset_postdata();
             endif;
            ?>
        </div>
    </div> 
</section>
<!-- blog-section - end  ================================================== -->
<?php }elseif ($blog_format == '2') { ?>

     <div class="grid">
        <div class="grid-sizer"></div>
        <?php if ( $blogPost->have_posts() ) : ?>
        <?php while ( $blogPost->have_posts() ) : $blogPost->the_post(); ?>
        <div class="grid-item" data-aos="fade-up" data-aos-delay="200">
            <div class="blog-grid">
                <div class="post-date">
                    <strong><?php echo get_the_date('d'); ?></strong>
                    <span><?php echo get_the_date('M'); ?></span>
                </div>
                <?php 
                    if(has_post_thumbnail()):
                    the_post_thumbnail();
                    endif; 
                ?>
                <div class="item-content">
                    <h3 class="item-title mb-30">
                        <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                    </h3>
                    <p><?php echo  wp_trim_words( get_the_content(), 35, false ); ?></p>
                    <div class="row align-items-center">
                        <div class="col-7">
                            <div class="post-admin clearfix">
                                <?php echo get_avatar(get_the_author_meta('ID'), 120, array('rating' => get_option('avatar_rating')), '', array('class' => 'admin-thumbnail')) ?>
                                <div class="admin-content">
                                    <?php echo  esc_html_e('By', 'kitbe'); ?><a href="#!"><?php echo get_the_author(); ?></a>
                                </div>
                            </div>
                        </div>
                        <div class="col-5 text-right">
                            <a href="<?php the_permalink(); ?>" class="btn"><?php echo  esc_html_e('Read More', 'kitbe'); ?></a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php  
          endwhile;
          wp_reset_postdata();

        ?>
    </div>
    <?php kitbe_blog_pagination(); ?>

   
<?php endif; }else{ } ?>
  <?php 
 } 

    public function load_widget_script(){
        if( \Elementor\Plugin::$instance->editor->is_edit_mode() === true  ) {
        ?>
        <script>
        ( function( $ ){
            var img_grid = $('.grid');
            if( img_grid.length ) {
                img_grid.imagesLoaded(function () {
                    img_grid.masonry({
                        itemSelector: '.grid-item',
                        percentPosition: true,
                        columnWidth: '.grid-sizer'
                    });
                });
            }
        })(jQuery);
        </script>
        <?php 
        }
    }

 }

