<?php
namespace kitbeCore\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;
use WP_Query;
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}
/**
 * Text Typing Effect
 *
 * Elementor widget for text typing effect.
 *
 * @since 1.7.0
 */
class kitbe_client_say extends Widget_Base {

    public function get_name() {
        return 'kitbe_client_say';
    }

    public function get_title() {
        return esc_html__( 'Testimonials Section', 'kitbe-core' );
    }

    public function get_icon() {
        return 'eicon-info-box';
    }

    public function get_categories() {
        return [ 'kitbe-elements' ];
    }
    protected function _register_controls() {
        // ------------------------------ Title ------------------------------
        $this->start_controls_section(
            'testimonials_title',
            [
                'label' => __( 'Testimonials Section', 'kitbe-core' ),
            ]
        );
	    $this->add_control(
		    'sec_style', [
			    'label' => esc_html__( 'Select Style', 'kitbe-core' ),
			    'type' => Controls_Manager::SELECT,
			    'options' => [
				    'style_1' => 'Style One'
			    ],
			    'default'   => 'style_1'
		    ]
	    );
	    $this->add_control(
		    'sec_title', [
			    'label' => esc_html__( 'Select Title', 'kitbe-core' ),
			    'type' => Controls_Manager::TEXT,
			    'default'   => 'Testimonials'
		    ]
	    );
	    $this->add_control(
		    'sec_sub_title', [
			    'label' => esc_html__( 'Select Sub Title', 'kitbe-core' ),
			    'type' => Controls_Manager::TEXTAREA,
			    'default'   => 'What clients say'
		    ]
	    );
	    $this->add_control(
            'feature_images',
            [
                'label' => esc_html__( 'Background Feature Images', 'niobis-core' ),
                'type' => Controls_Manager::MEDIA,
                'default'   => [
                    'url'   => plugins_url( '/images/paper_5.png', __FILE__ )
                ]
                
            ]
        );
        $this->add_control(
            'feature_top',
            [
                'label' => esc_html__( 'Top Feature Images', 'niobis-core' ),
                'type' => Controls_Manager::MEDIA,
                'default'   => [
                    'url'   => plugins_url( '/images/paper_5.png', __FILE__ )
                ]
                
            ]
        );

        $this->end_controls_section();

        $testimonials_list = new \Elementor\Repeater();
	    $this->start_controls_section(
		    'testi_section',
		    [
			    'label' => __( 'Testimonials Information', 'kitbe-core' ),
		    ]
	    );
	    
	    $testimonials_list->add_control(
		    'name',
		    [
			    'label'     => __( 'Name', 'kitbe-core' ),
			    'type'      => Controls_Manager::TEXT,
			    'label_block'=> true,
                'default'   => 'Emonis Mhidiuy'
		    ]
	    );
	     $testimonials_list->add_control(
		    'designation',
		    [
			    'label'     => __( 'Designation', 'kitbe-core' ),
			    'type'      => Controls_Manager::TEXT,
			    'label_block'=> true,
                'default'   => 'CEO at Droitthemes'
		    ]
	    );
	    $testimonials_list->add_control(
		    'review_Ratting',
		    [
			    'label'     => __( 'Review Ratting', 'kitbe-core' ),
			    'type'      => Controls_Manager::NUMBER,
			    'label_block'=> true,
                'default'   => '5'
		    ]
	    );
	    $testimonials_list->add_control(
		    'feature_img',
		    [
			    'label'     => __( 'Feature Images', 'kitbe-core' ),
			    'type'      => Controls_Manager::MEDIA,
			    'label_block'=> true,
                'default'   => [
                    'url'   => plugins_url( '/images/client.jpg', __FILE__ )
                ]
		    ]
	    );
	    $testimonials_list->add_control(
		    'testi_content',
		    [
			    'label'     => __( 'Testimonials Content', 'kitbe-core' ),
			    'type'      => Controls_Manager::WYSIWYG,
			    'label_block'=> true,
                'default'   => 'Lorem ipsum dolor ametod to consectetur in to in the final way to the adipiscing to make it ealsy. ipsum dolor ametod to consectetur in to in the final way to the adipiscing to make it ealsy ipsum dolor ametod to consectetur in to in the final way  to make it.'
		    ]
	    );    
	    $this->add_control(
		    'test_info',
		    [
			    'label'     => __( 'Price Tabs', 'kitbe-core' ),
			    'type'      => Controls_Manager::REPEATER,
			    'fields'    => $testimonials_list->get_controls(),
			    'title_field'=> '{{{ name }}}',
		    ]
	    );
        $this->end_controls_section();

        //---------------- End Testimonials Section --------------- // 

        //---------------- Style Section --------------- // 
		$this->start_controls_section(
			'testimonais_section_style', [
				'label' => __( 'Section Style', 'kitbe-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
            'title_color', [
                'label' => __( 'Title Text Color', 'kitbe-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title .sub-title' => 'color: {{VALUE}};', 
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(), [
                'label' => 'Typography',
                'name' => 'typography_title',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .section-title .sub-title',
                
            ]
        );
        $this->add_control(
            'sub_title_color', [
                'label' => __( 'Sub Title Text Color', 'kitbe-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title .title-text' => 'color: {{VALUE}};', 
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(), [
                'label' => 'Typography',
                'name' => 'typography_sub_title',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .section-title .title-text',
                
            ]
        );
      $this->end_controls_section();   ///(Style) End The Team Title Section

      //---------------- Testimonaisl Information Section --------------- // 
		$this->start_controls_section(
			'testimonais_list_style', [
				'label' => __( 'Testimonaisl Info Style', 'kitbe-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
            'name_color', [
                'label' => __( 'Name Text Color', 'kitbe-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .abmin-name' => 'color: {{VALUE}};', 
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(), [
                'label' => 'Name Typography',
                'name' => 'typography_name',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .abmin-name',
                
            ]
        );
        $this->add_control(
            'designation_color', [
                'label' => __( 'Designation Text Color', 'kitbe-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .abmin-title' => 'color: {{VALUE}};', 
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(), [
                'label' => 'Designation Typography',
                'name' => 'typography_designation',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .abmin-title',
                
            ]
        );
        $this->add_control(
            'content_color', [
                'label' => __( 'Content Text Color', 'kitbe-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .item p' => 'color: {{VALUE}};', 
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(), [
                'label' => 'Content Typography',
                'name' => 'typography_content',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .item p',
                
            ]
        );
      $this->end_controls_section();   ///(Style) End The Team Title Section

      
    }
    protected function render() {
    $this->load_widget_script();	
	$settings = $this->get_settings();
	$sec_title     = $settings['sec_title'];
	$sec_sub_title = $settings['sec_sub_title'];
	$test_info     = $settings['test_info'];

	if( $settings['sec_style'] == 'style_1' ):
?>
<!-- pricing-section - start ================================================== -->

<section id="testimonial-section" class="testimonial-section sec-ptb-120 deco-wrap clearfix">
	<div class="container">

		<div class="row mb-60 justify-content-center">
			<div class="col-lg-6 col-md-7 col-sm-8 col-xs-12" data-aos="fade-up" data-aos-delay="100">
				<div class="section-title text-center">
					
					<?php if(!empty($sec_title)): ?>
					<h2 class="title-text mb-15"><?php echo wp_kses_post($sec_title); ?></h2>
					<?php endif; ?>
					<?php if(!empty($sec_sub_title)): ?>
					<p class="mb-0">
					<?php echo wp_kses_post($sec_sub_title); ?>
					</p>
					<?php endif; ?>
				</div>
			</div>
		</div>

		<div class="row align-items-center justify-content-lg-between justify-content-md-center justify-content-sm-center">
			<div class="col-lg-4 col-md-6 col-sm-7 col-xs-12">
				<div class="carousel_thumb" data-slider-id="1">
					<?php 
	                  if($test_info){ 
	                  foreach ($test_info as $client_say) {
	                ?>
					<button class="thumb-item" data-aos="zoom-out" data-aos-delay="300">
						<img src="<?php echo esc_url($client_say['feature_img']['url']); ?>" alt="image_not_found">
					</button>
					<?php } } ?>
					
				</div>
			</div>

			<div class="col-lg-5 col-md-7 col-sm-8 col-xs-12" data-aos="fade-up" data-aos-delay="500">
				<div class="teatimonial_carousel owl-carousel owl-theme" data-slider-id="1">
					<?php 
	                  if($test_info){ 
	                  foreach ($test_info as $client_say) {
	                  	$star = $client_say['review_Ratting'];
	                ?>
					<div class="item">
						<span class="quote-icon">
							<i class="fas fa-quote-left"></i>
						</span>
						<div class="rating-star ul-li">
							<ul class="clearfix">
								<?php for($i=1; $i<= $star; $i++){ ?>
								<li><i class="fas fa-star"></i></li>
								<?php } ?>
							</ul>
						</div>
						<p><?php echo esc_html($client_say['testi_content']); ?></p>
						<div class="testimonial-admin">
							<div class="admin-image">
								<img src="<?php echo esc_url($client_say['feature_img']['url']); ?>" alt="image_not_found">
							</div>
							<div class="admin-content">
								<h4 class="abmin-name"><?php echo esc_html($client_say['name']); ?></h4>
								<span class="abmin-title"><?php echo esc_html($client_say['designation']); ?></span>
							</div>
						</div>
					</div>
					<?php } } ?>
				</div>
			</div>
		</div>
	</div>
	<?php if(!empty($settings['feature_top']['url'])): ?>
	<div class="deco-image deco-image-1" data-aos="fade-left" data-aos-delay="200">
		<img src="<?php echo esc_url($settings['feature_top']['url']); ?>" alt="box_dot_image">
	</div>
    <?php endif; ?>
    <?php if(!empty($settings['feature_images']['url'])): ?>
	<div class="deco-image deco-image-2" data-aos="fade-right" data-aos-delay="200">
		<img src="<?php echo esc_url($settings['feature_images']['url']); ?>" alt="box_dot_image">
	</div>
	<?php endif; ?>
</section>
	<!-- pricing-section - end ================================================== -->
	<?php 
    endif;
    }

    public function load_widget_script(){
        if( \Elementor\Plugin::$instance->editor->is_edit_mode() === true  ) {
        ?>
        <script>
        ( function( $ ){
            var img_grid = $('.grid');
            if( img_grid.length ) {
                img_grid.imagesLoaded(function () {
                    img_grid.masonry({
                        itemSelector: '.grid-item',
                        percentPosition: true,
                        columnWidth: '.grid-sizer'
                    });
                });
            }
        })(jQuery);
        </script>
        <?php 
        }
    }

}