<?php
namespace kitbeCore\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;
use WP_Query;
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}
/**
 * Text Typing Effect
 *
 * Elementor widget for text typing effect.
 *
 * @since 1.7.0
 */
class kitbe_hero_slide extends Widget_Base {

    public function get_name() {
        return 'kitbe_hero_slide';
    }

    public function get_title() {
        return esc_html__( 'Hero Slider', 'kitbe-core' );
    }

    public function get_icon() {
        return 'eicon-info-box';
    }

    public function get_categories() {
        return [ 'kitbe-elements' ];
    }
    protected function _register_controls() {
       $heroslide_carousel = new \Elementor\Repeater();
	    $this->start_controls_section(
		    'heroslide_carousel_sec',
		    [
			    'label' => __( 'Slider Information', 'kitbe-core' ),
			    'condition' => [
                    'sec_style' => ['style_1','style_2']
                ],
		    ]
	    );
	    $heroslide_carousel->add_control(
		    'slide_title',
		    [
			    'label'     => __( 'Slide Title', 'kitbe-core' ),
			    'type'      => Controls_Manager::TEXT,
			    'label_block'=> true,
                'default'   => 'We Make your home looks Twenty years younger.'
		    ]
	    );
	    $heroslide_carousel->add_control(
		    'feature_desc',
		    [
			    'label'     => __( 'Slider Sub Title', 'kitbe-core' ),
			    'type'      => Controls_Manager::TEXTAREA,
			    'label_block'=> true,
                'default'   => 'Dont get shirty with me chinwag say bleeder hanky  panky so we an to fidn I said  ar re fedr raere.'
		    ]
	    );
	    $heroslide_carousel->add_control(
		    'feature_img',
		    [
			    'label'     => __( 'Feature Image', 'kitbe-core' ),
			    'type'      => Controls_Manager::MEDIA,
			    'label_block'=> true,
                'default'   => [
                    'url'   => plugins_url( '/images/slide.jpg', __FILE__ )
                ]
		    ]
	    );
	    $heroslide_carousel->add_control(
		    'btn_label',
		    [
			    'label'     => __( 'Button Label', 'kitbe-core' ),
			    'type'      => Controls_Manager::TEXT,
			    'label_block'=> true,
                'default'   => 'Get Started'
		    ]
	    );
	    $heroslide_carousel->add_control(
		    'btn_url',
		    [
			    'label'     => __( 'Button URL', 'kitbe-core' ),
			    'type'      => Controls_Manager::URL,
			    'label_block'=> true,
		    ]
	    );
	    $this->add_control(
		    'hero_slider',
		    [
			    'label'     => __( 'Slider Tabs', 'kitbe-core' ),
			    'type'      => Controls_Manager::REPEATER,
			    'fields'    => $heroslide_carousel->get_controls(),
			    'title_field'=> '{{{ slide_title }}}',
		    ]
	    );
        $this->end_controls_section();
        //---------------- End Slider Section --------------- // 

        //---------------- Style Section --------------- // 
		$this->start_controls_section(
			'slide_style', [
				'label' => __( 'Slide Title', 'kitbe-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
            'title_color', [
                'label' => __( 'Title Text Color', 'kitbe-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slider-content .title-text' => 'color: {{VALUE}};', 
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(), [
                'label' => 'Typography',
                'name' => 'typography_title',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .slider-content .title-text',
                
            ]
        );
        $this->end_controls_section();   ///(Style) End The Slide Title Section
        $this->start_controls_section(
			'slide_sub_style', [
				'label' => __( 'Slide Sub Title', 'kitbe-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'sub_title_color', [
				'label' => __( 'Sub Title Color', 'kitbe-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
                    '{{WRAPPER}} .slider-content p' => 'color: {{VALUE}};', 
                ],
				
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(), [
                'label' => 'Typography',
                'name' => 'typography_sub_title',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .slider-content p',
                
            ]
        );
        $this->end_controls_section();   /// End The Controls Section
        // Slide Button
        $this->start_controls_section(
			'slide_button', [
				'label' => __( 'Slide Button', 'kitbe-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'button_bg_color', [
				'label' => __( 'Background Color', 'kitbe-core' ),
				'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn' => 'background: {{VALUE}};', 
                ],
			]
		);
		$this->add_control(
			'button_text_color', [
				'label' => __( 'Button Text Color', 'kitbe-core' ),
				'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn' => 'color: {{VALUE}};', 
                ],
			]
		);
	    $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'label' => 'Typography',
                'name' => 'typography_button',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .btn',
                
            ]
        );
      $this->end_controls_section();       
    }
    protected function render() {
    	$this->load_widget_script();
        $settings = $this->get_settings();
        $slider_list = $settings['hero_slider'];
	   ?>
	    
    	<!-- slider-section - start
		================================================== -->
		<section id="slider-section" class="slider-section clearfix">
			<div id="main-carousel" class="main-carousel owl-carousel owl-theme arrow-right-left">
				<?php
                   if( is_array( $slider_list ) && count( $slider_list ) > 0 ){
                   	$i      = 0;
                    foreach ( $slider_list as $slider_info ){
                    $feature_images = $slider_info['feature_img']['url'];
                 ?> 
				<div class="item d-flex align-items-center" data-background="<?php echo esc_url($feature_images); ?>">
					<div class="container">
						<div class="row justify-content-center">
							<div class="col-lg-9 col-md-12">

								<div class="slider-content pl-0 text-center text-white">
									<h3 class="title-text">
										<?php echo esc_html($slider_info['slide_title']); ?>
									</h3>
									<p class="slidetwo"><?php echo esc_html($slider_info['feature_desc']); ?></p>
									<a href="<?php echo esc_url($slider_info['btn_url']['url']); ?>" class="btn bg-default-orange"><?php echo esc_html($slider_info['btn_label']); ?></a>
								</div>
								
							</div>
						</div>
					</div>
				</div>
				<?php }} ?>
			</div>
		</section>
		<?php 
    }
    public function load_widget_script(){
	    if( \Elementor\Plugin::$instance->editor->is_edit_mode() === true  ) {
	        ?>
	        <script>
	            ( function( $ ){
	            	// Start custom js function
							                  // main carousel - start
						  // --------------------------------------------------
						  $('#main-carousel').owlCarousel({
						    items:1,
						    margin:0,
						    nav:true,
						    loop:true,
						    dots:false,
						    autoplay:true,
						    smartSpeed:1200,
						    autoplayTimeout:8000,
						    autoplayHoverPause:true
						  });
						  // main carousel - end
						  // --------------------------------------------------
											// End Custome js function

	            })(jQuery);
	        </script>
	        <?php
	    }
	}
}